@@ -5,6 +5,7 @@
 */
 #include "plaintexteditor.h"
 
+#include "config-textcustomeditor.h"
 #include "widgets/textmessageindicator.h"
 #include <KConfig>
 #include <KConfigGroup>
@@ -17,7 +18,7 @@
 #include <QActionGroup>
 #include <QIcon>
 
-#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
 #include <Sonnet/Dialog>
@@ -194,7 +195,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
             }
         }
         if (d->supportFeatures & TextToSpeech) {
-#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
             if (!emptyDocument) {
                 QAction *speakAction = popup->addAction(i18n("Speak Text"));
                 speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
