@@ -44,12 +44,17 @@ TextTranslator::TranslatorEnginePlugin *DeeplEngineClient::createTranslator()
     return enginePlugin;
 }
 
-QMap<TextTranslator::TranslatorUtil::Language, QString> DeeplEngineClient::supportedLanguages()
+QMap<TextTranslator::TranslatorUtil::Language, QString> DeeplEngineClient::supportedFromLanguages()
 {
-    if (mLanguages.isEmpty()) {
-        mLanguages = fillLanguages();
+    if (mFromLanguages.isEmpty()) {
+        mFromLanguages = fillLanguages();
     }
-    return mLanguages;
+    return mFromLanguages;
+}
+
+QMap<TextTranslator::TranslatorUtil::Language, QString> DeeplEngineClient::supportedToLanguages()
+{
+    return supportedFromLanguages();
 }
 
 bool DeeplEngineClient::isSupported(TextTranslator::TranslatorUtil::Language lang) const
@@ -95,8 +100,9 @@ bool DeeplEngineClient::hasConfigurationDialog() const
     return true;
 }
 
-void DeeplEngineClient::showConfigureDialog(QWidget *parentWidget)
+bool DeeplEngineClient::showConfigureDialog(QWidget *parentWidget)
 {
+    bool settingsChanged = false;
     QPointer<DeeplEngineConfigureDialog> dlg = new DeeplEngineConfigureDialog(parentWidget);
     KConfigGroup myGroup(KSharedConfig::openConfig(), DeeplEngineUtil::groupName());
     dlg->setUseFreeLicenceKey(myGroup.readEntry(DeeplEngineUtil::freeLicenseKey(), false));
@@ -123,8 +129,15 @@ void DeeplEngineClient::showConfigureDialog(QWidget *parentWidget)
         writeJob->setTextData(dlg->apiKey());
         writeJob->start();
         Q_EMIT configureChanged();
+        settingsChanged = true;
     }
     delete dlg;
+    return settingsChanged;
+}
+
+TextTranslator::TranslatorEngineClient::EngineType DeeplEngineClient::engineType() const
+{
+    return TextTranslator::TranslatorEngineClient::Network;
 }
 
 void DeeplEngineClient::slotPasswordWritten(QKeychain::Job *baseJob)
